pub struct RootError { /* private fields */ }Available on crate feature
permission-calculator only.Expand description
Error calculating permissions with information in a cache.
Implementations
Sourceimpl RootError
impl RootError
Sourcepub const fn kind(&self) -> &RootErrorType
pub const fn kind(&self) -> &RootErrorType
Immutable reference to the type of error that occurred.
Sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
Sourcepub fn into_parts(self) -> (RootErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts(self) -> (RootErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.